"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.clouddesktop.v1.desktop_pb2
import yandex.cloud.clouddesktop.v1.desktop_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class DesktopServiceStub:
    """A set of methods for managing desktop resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.GetDesktopRequest,
        yandex.cloud.clouddesktop.v1.desktop_pb2.Desktop,
    ]
    """Returns the specified desktop resource.

    To get the list of available desktops, make a [List] request.
    """

    GetRdpFile: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.GetRdpFileRequest,
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.RdpFileResponse,
    ]
    """Returns a RDP file for the specified desktop."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.ListDesktopsRequest,
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.ListDesktopsResponse,
    ]
    """Retrieves the list of desktop resources."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.ListDesktopOperationsRequest,
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.ListDesktopOperationsResponse,
    ]
    """Returns list of the operations for the specified desktop."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.CreateDesktopRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates desktop in the specified folder."""

    UpdateProperties: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.UpdatePropertiesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates desktop properties."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.DeleteDesktopRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified desktop."""

    ResetPassword: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.ResetPasswordRequest,
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.ResetPasswordResponse,
    ]
    """Reset password"""

    Restart: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.RestartRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Restart the specified desktop."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.UpdateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sync desktop with group configuration"""

    Start: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.StartRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Start the specified desktop."""

    Stop: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.StopRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stop the specified desktop."""

class DesktopServiceAsyncStub:
    """A set of methods for managing desktop resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.GetDesktopRequest,
        yandex.cloud.clouddesktop.v1.desktop_pb2.Desktop,
    ]
    """Returns the specified desktop resource.

    To get the list of available desktops, make a [List] request.
    """

    GetRdpFile: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.GetRdpFileRequest,
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.RdpFileResponse,
    ]
    """Returns a RDP file for the specified desktop."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.ListDesktopsRequest,
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.ListDesktopsResponse,
    ]
    """Retrieves the list of desktop resources."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.ListDesktopOperationsRequest,
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.ListDesktopOperationsResponse,
    ]
    """Returns list of the operations for the specified desktop."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.CreateDesktopRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates desktop in the specified folder."""

    UpdateProperties: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.UpdatePropertiesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates desktop properties."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.DeleteDesktopRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified desktop."""

    ResetPassword: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.ResetPasswordRequest,
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.ResetPasswordResponse,
    ]
    """Reset password"""

    Restart: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.RestartRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Restart the specified desktop."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.UpdateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sync desktop with group configuration"""

    Start: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.StartRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Start the specified desktop."""

    Stop: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_service_pb2.StopRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stop the specified desktop."""

class DesktopServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing desktop resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_service_pb2.GetDesktopRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.clouddesktop.v1.desktop_pb2.Desktop, collections.abc.Awaitable[yandex.cloud.clouddesktop.v1.desktop_pb2.Desktop]]:
        """Returns the specified desktop resource.

        To get the list of available desktops, make a [List] request.
        """

    @abc.abstractmethod
    def GetRdpFile(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_service_pb2.GetRdpFileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.clouddesktop.v1.desktop_service_pb2.RdpFileResponse, collections.abc.Awaitable[yandex.cloud.clouddesktop.v1.desktop_service_pb2.RdpFileResponse]]:
        """Returns a RDP file for the specified desktop."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_service_pb2.ListDesktopsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.clouddesktop.v1.desktop_service_pb2.ListDesktopsResponse, collections.abc.Awaitable[yandex.cloud.clouddesktop.v1.desktop_service_pb2.ListDesktopsResponse]]:
        """Retrieves the list of desktop resources."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_service_pb2.ListDesktopOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.clouddesktop.v1.desktop_service_pb2.ListDesktopOperationsResponse, collections.abc.Awaitable[yandex.cloud.clouddesktop.v1.desktop_service_pb2.ListDesktopOperationsResponse]]:
        """Returns list of the operations for the specified desktop."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_service_pb2.CreateDesktopRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates desktop in the specified folder."""

    @abc.abstractmethod
    def UpdateProperties(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_service_pb2.UpdatePropertiesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates desktop properties."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_service_pb2.DeleteDesktopRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified desktop."""

    @abc.abstractmethod
    def ResetPassword(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_service_pb2.ResetPasswordRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.clouddesktop.v1.desktop_service_pb2.ResetPasswordResponse, collections.abc.Awaitable[yandex.cloud.clouddesktop.v1.desktop_service_pb2.ResetPasswordResponse]]:
        """Reset password"""

    @abc.abstractmethod
    def Restart(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_service_pb2.RestartRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Restart the specified desktop."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_service_pb2.UpdateRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sync desktop with group configuration"""

    @abc.abstractmethod
    def Start(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_service_pb2.StartRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Start the specified desktop."""

    @abc.abstractmethod
    def Stop(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_service_pb2.StopRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Stop the specified desktop."""

def add_DesktopServiceServicer_to_server(servicer: DesktopServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/clouddesktop/v1/desktop_image_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/clouddesktop/v1/desktop_image_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.clouddesktop.v1 import desktop_image_pb2 as yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__image__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/clouddesktop/v1/desktop_image_service.proto\x12 yandex.cloud.clouddesktop.v1.api\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x30yandex/cloud/clouddesktop/v1/desktop_image.proto\x1a google/protobuf/field_mask.proto\"\xb8\x01\n\x18ListDesktopImagesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x15 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x16 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x17 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x18 \x01(\tB\t\x8a\xc8\x31\x05<=100J\x04\x08\x02\x10\x15\"\x82\x01\n\x19ListDesktopImagesResponse\x12\x46\n\x0e\x64\x65sktop_images\x18\x01 \x03(\x0b\x32..yandex.cloud.clouddesktop.v1.api.DesktopImage\x12\x17\n\x0fnext_page_token\x18\x16 \x01(\tJ\x04\x08\x02\x10\x16\"|\n\x17\x43opyDesktopImageRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x04name\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1e\n\x08image_id\x18\x08 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50J\x04\x08\x03\x10\x08\"\xc2\x02\n\x19UpdateDesktopImageRequest\x12\x16\n\x08image_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x16\n\x04name\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x94\x01\n\x06labels\x18\x04 \x03(\x0b\x32G.yandex.cloud.clouddesktop.v1.api.UpdateDesktopImageRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"u\n\x16\x43opyFromDesktopRequest\x12\x1b\n\tfolder_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x16\n\x04name\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12 \n\ndesktop_id\x18\x08 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50J\x04\x08\x05\x10\x08\",\n\x18\x43opyDesktopImageMetadata\x12\x10\n\x08image_id\x18\x01 \x01(\t\"+\n\x17\x43opyFromDesktopMetadata\x12\x10\n\x08image_id\x18\x01 \x01(\t\"3\n\x19\x44\x65leteDesktopImageRequest\x12\x16\n\x08image_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\".\n\x1a\x44\x65leteDesktopImageMetadata\x12\x10\n\x08image_id\x18\x01 \x01(\t\"0\n\x16GetDesktopImageRequest\x12\x16\n\x08image_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"4\n\x1aUpdateDesktopImageMetadata\x12\x16\n\x08image_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xfe\x08\n\x13\x44\x65sktopImageService\x12\xa1\x01\n\x04List\x12:.yandex.cloud.clouddesktop.v1.api.ListDesktopImagesRequest\x1a;.yandex.cloud.clouddesktop.v1.api.ListDesktopImagesResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/cloud-desktop/v1/images\x12\x9c\x01\n\x03Get\x12\x38.yandex.cloud.clouddesktop.v1.api.GetDesktopImageRequest\x1a..yandex.cloud.clouddesktop.v1.api.DesktopImage\"+\x82\xd3\xe4\x93\x02%\x12#/cloud-desktop/v1/images/{image_id}\x12\xba\x01\n\x04\x43opy\x12\x39.yandex.cloud.clouddesktop.v1.api.CopyDesktopImageRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*(\n\x18\x43opyDesktopImageMetadata\x12\x0c\x44\x65sktopImage\x82\xd3\xe4\x93\x02\"\"\x1d/cloud-desktop/v1/images:copy:\x01*\x12\xc6\x01\n\x06Update\x12;.yandex.cloud.clouddesktop.v1.api.UpdateDesktopImageRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2**\n\x1aUpdateDesktopImageMetadata\x12\x0c\x44\x65sktopImage\x82\xd3\xe4\x93\x02(2#/cloud-desktop/v1/images/{image_id}:\x01*\x12\xce\x01\n\x0f\x43opyFromDesktop\x12\x38.yandex.cloud.clouddesktop.v1.api.CopyFromDesktopRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*\'\n\x17\x43opyFromDesktopMetadata\x12\x0c\x44\x65sktopImage\x82\xd3\xe4\x93\x02-\"(/cloud-desktop/v1/images:copyFromDesktop:\x01*\x12\xcc\x01\n\x06\x44\x65lete\x12;.yandex.cloud.clouddesktop.v1.api.DeleteDesktopImageRequest\x1a!.yandex.cloud.operation.Operation\"b\xb2\xd2*3\n\x1a\x44\x65leteDesktopImageMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02%*#/cloud-desktop/v1/images/{image_id}Bq\n yandex.cloud.api.clouddesktop.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktopb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.clouddesktop.v1.desktop_image_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n yandex.cloud.api.clouddesktop.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktop'
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_COPYDESKTOPIMAGEREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_COPYDESKTOPIMAGEREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_COPYDESKTOPIMAGEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_COPYDESKTOPIMAGEREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_COPYDESKTOPIMAGEREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_COPYDESKTOPIMAGEREQUEST'].fields_by_name['image_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEDESKTOPIMAGEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEDESKTOPIMAGEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEDESKTOPIMAGEREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_UPDATEDESKTOPIMAGEREQUEST'].fields_by_name['image_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEDESKTOPIMAGEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEDESKTOPIMAGEREQUEST'].fields_by_name['name']._serialized_options = b'\212\3101\004<=50'
  _globals['_UPDATEDESKTOPIMAGEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEDESKTOPIMAGEREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_COPYFROMDESKTOPREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_COPYFROMDESKTOPREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_COPYFROMDESKTOPREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_COPYFROMDESKTOPREQUEST'].fields_by_name['name']._serialized_options = b'\212\3101\004<=50'
  _globals['_COPYFROMDESKTOPREQUEST'].fields_by_name['desktop_id']._loaded_options = None
  _globals['_COPYFROMDESKTOPREQUEST'].fields_by_name['desktop_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEDESKTOPIMAGEREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_DELETEDESKTOPIMAGEREQUEST'].fields_by_name['image_id']._serialized_options = b'\350\3071\001'
  _globals['_GETDESKTOPIMAGEREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_GETDESKTOPIMAGEREQUEST'].fields_by_name['image_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEDESKTOPIMAGEMETADATA'].fields_by_name['image_id']._loaded_options = None
  _globals['_UPDATEDESKTOPIMAGEMETADATA'].fields_by_name['image_id']._serialized_options = b'\350\3071\001'
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\032\022\030/cloud-desktop/v1/images'
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002%\022#/cloud-desktop/v1/images/{image_id}'
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['Copy']._loaded_options = None
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['Copy']._serialized_options = b'\262\322*(\n\030CopyDesktopImageMetadata\022\014DesktopImage\202\323\344\223\002\"\"\035/cloud-desktop/v1/images:copy:\001*'
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322**\n\032UpdateDesktopImageMetadata\022\014DesktopImage\202\323\344\223\002(2#/cloud-desktop/v1/images/{image_id}:\001*'
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['CopyFromDesktop']._loaded_options = None
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['CopyFromDesktop']._serialized_options = b'\262\322*\'\n\027CopyFromDesktopMetadata\022\014DesktopImage\202\323\344\223\002-\"(/cloud-desktop/v1/images:copyFromDesktop:\001*'
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*3\n\032DeleteDesktopImageMetadata\022\025google.protobuf.Empty\202\323\344\223\002%*#/cloud-desktop/v1/images/{image_id}'
  _globals['_LISTDESKTOPIMAGESREQUEST']._serialized_start=314
  _globals['_LISTDESKTOPIMAGESREQUEST']._serialized_end=498
  _globals['_LISTDESKTOPIMAGESRESPONSE']._serialized_start=501
  _globals['_LISTDESKTOPIMAGESRESPONSE']._serialized_end=631
  _globals['_COPYDESKTOPIMAGEREQUEST']._serialized_start=633
  _globals['_COPYDESKTOPIMAGEREQUEST']._serialized_end=757
  _globals['_UPDATEDESKTOPIMAGEREQUEST']._serialized_start=760
  _globals['_UPDATEDESKTOPIMAGEREQUEST']._serialized_end=1082
  _globals['_UPDATEDESKTOPIMAGEREQUEST_LABELSENTRY']._serialized_start=1037
  _globals['_UPDATEDESKTOPIMAGEREQUEST_LABELSENTRY']._serialized_end=1082
  _globals['_COPYFROMDESKTOPREQUEST']._serialized_start=1084
  _globals['_COPYFROMDESKTOPREQUEST']._serialized_end=1201
  _globals['_COPYDESKTOPIMAGEMETADATA']._serialized_start=1203
  _globals['_COPYDESKTOPIMAGEMETADATA']._serialized_end=1247
  _globals['_COPYFROMDESKTOPMETADATA']._serialized_start=1249
  _globals['_COPYFROMDESKTOPMETADATA']._serialized_end=1292
  _globals['_DELETEDESKTOPIMAGEREQUEST']._serialized_start=1294
  _globals['_DELETEDESKTOPIMAGEREQUEST']._serialized_end=1345
  _globals['_DELETEDESKTOPIMAGEMETADATA']._serialized_start=1347
  _globals['_DELETEDESKTOPIMAGEMETADATA']._serialized_end=1393
  _globals['_GETDESKTOPIMAGEREQUEST']._serialized_start=1395
  _globals['_GETDESKTOPIMAGEREQUEST']._serialized_end=1443
  _globals['_UPDATEDESKTOPIMAGEMETADATA']._serialized_start=1445
  _globals['_UPDATEDESKTOPIMAGEMETADATA']._serialized_end=1497
  _globals['_DESKTOPIMAGESERVICE']._serialized_start=1500
  _globals['_DESKTOPIMAGESERVICE']._serialized_end=2650
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/mongodb/v1/config/mongodb4_2.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/mongodb/v1/config/mongodb4_2.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/mdb/mongodb/v1/config/mongodb4_2.proto\x12\"yandex.cloud.mdb.mongodb.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xcb\x10\n\x0fMongodConfig4_2\x12L\n\x07storage\x18\x01 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage\x12\x63\n\x13operation_profiling\x18\x02 \x01(\x0b\x32\x46.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.OperationProfiling\x12H\n\x03net\x18\x03 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Network\x12W\n\rset_parameter\x18\x04 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.SetParameter\x1a\xd4\x07\n\x07Storage\x12[\n\x0bwired_tiger\x18\x01 \x01(\x0b\x32\x46.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger\x12T\n\x07journal\x18\x02 \x01(\x0b\x32\x43.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.Journal\x1a\xc9\x05\n\nWiredTiger\x12j\n\rengine_config\x18\x01 \x01(\x0b\x32S.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.EngineConfig\x12r\n\x11\x63ollection_config\x18\x02 \x01(\x0b\x32W.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.CollectionConfig\x12h\n\x0cindex_config\x18\x03 \x01(\x0b\x32R.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.IndexConfig\x1a\x43\n\x0c\x45ngineConfig\x12\x33\n\rcache_size_gb\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a\xe4\x01\n\x10\x43ollectionConfig\x12|\n\x10\x62lock_compressor\x18\x01 \x01(\x0e\x32\x62.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Storage.WiredTiger.CollectionConfig.Compressor\"R\n\nCompressor\x12\x1a\n\x16\x43OMPRESSOR_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\n\n\x06SNAPPY\x10\x02\x12\x08\n\x04ZLIB\x10\x03\x12\x08\n\x04ZSTD\x10\x04\x1a\x45\n\x0bIndexConfig\x12\x36\n\x12prefix_compression\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1aJ\n\x07Journal\x12?\n\x0f\x63ommit_interval\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x31-500\x1a\xb0\x02\n\x12OperationProfiling\x12Y\n\x04mode\x18\x01 \x01(\x0e\x32K.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.OperationProfiling.Mode\x12>\n\x11slow_op_threshold\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x42\n\x13slow_op_sample_rate\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x07\xfa\xc7\x31\x03\x30-1\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x07\n\x03OFF\x10\x01\x12\x0b\n\x07SLOW_OP\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x1a\x8e\x03\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\x12\\\n\x0b\x63ompression\x18\x02 \x01(\x0b\x32G.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Network.Compression\x1a\xd7\x01\n\x0b\x43ompression\x12p\n\x0b\x63ompressors\x18\x01 \x03(\x0e\x32R.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2.Network.Compression.CompressorB\x07\x82\xc8\x31\x03\x31-3\"V\n\nCompressor\x12\x1a\n\x16\x43OMPRESSOR_UNSPECIFIED\x10\x00\x12\n\n\x06SNAPPY\x10\x01\x12\x08\n\x04ZLIB\x10\x02\x12\x08\n\x04ZSTD\x10\x03\x12\x0c\n\x08\x44ISABLED\x10\x04\x1aG\n\x0cSetParameter\x12\x37\n\x13\x65nable_flow_control\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x8c\x07\n\x11MongoCfgConfig4_2\x12N\n\x07storage\x18\x01 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage\x12\x65\n\x13operation_profiling\x18\x02 \x01(\x0b\x32H.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.OperationProfiling\x12J\n\x03net\x18\x03 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Network\x1a\xaa\x02\n\x07Storage\x12]\n\x0bwired_tiger\x18\x01 \x01(\x0b\x32H.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger\x1a\xbf\x01\n\nWiredTiger\x12l\n\rengine_config\x18\x01 \x01(\x0b\x32U.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.Storage.WiredTiger.EngineConfig\x1a\x43\n\x0c\x45ngineConfig\x12\x33\n\rcache_size_gb\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a\xee\x01\n\x12OperationProfiling\x12[\n\x04mode\x18\x01 \x01(\x0e\x32M.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2.OperationProfiling.Mode\x12>\n\x11slow_op_threshold\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x07\n\x03OFF\x10\x01\x12\x0b\n\x07SLOW_OP\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x1aV\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\"\xec\x03\n\x0fMongosConfig4_2\x12H\n\x03net\x18\x01 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2.Network\x1a\x8e\x03\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\x12\\\n\x0b\x63ompression\x18\x02 \x01(\x0b\x32G.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2.Network.Compression\x1a\xd7\x01\n\x0b\x43ompression\x12p\n\x0b\x63ompressors\x18\x01 \x03(\x0e\x32R.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2.Network.Compression.CompressorB\x07\x82\xc8\x31\x03\x31-3\"V\n\nCompressor\x12\x1a\n\x16\x43OMPRESSOR_UNSPECIFIED\x10\x00\x12\n\n\x06SNAPPY\x10\x01\x12\x08\n\x04ZLIB\x10\x02\x12\x08\n\x04ZSTD\x10\x03\x12\x0c\n\x08\x44ISABLED\x10\x04\"\xfa\x01\n\x12MongodConfigSet4_2\x12M\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2\x12H\n\x0buser_config\x18\x02 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2\x12K\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongodConfig4_2\"\x82\x02\n\x14MongoCfgConfigSet4_2\x12O\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2\x12J\n\x0buser_config\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2\x12M\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig4_2\"\xfa\x01\n\x12MongosConfigSet4_2\x12M\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2\x12H\n\x0buser_config\x18\x02 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2\x12K\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x33.yandex.cloud.mdb.mongodb.v1.config.MongosConfig4_2Bx\n&yandex.cloud.api.mdb.mongodb.v1.configZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1/config;mongodbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mongodb.v1.config.mongodb4_2_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&yandex.cloud.api.mdb.mongodb.v1.configZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1/config;mongodb'
  _globals['_MONGODCONFIG4_2_STORAGE_JOURNAL'].fields_by_name['commit_interval']._loaded_options = None
  _globals['_MONGODCONFIG4_2_STORAGE_JOURNAL'].fields_by_name['commit_interval']._serialized_options = b'\372\3071\0051-500'
  _globals['_MONGODCONFIG4_2_OPERATIONPROFILING'].fields_by_name['slow_op_threshold']._loaded_options = None
  _globals['_MONGODCONFIG4_2_OPERATIONPROFILING'].fields_by_name['slow_op_threshold']._serialized_options = b'\372\3071\002>0'
  _globals['_MONGODCONFIG4_2_OPERATIONPROFILING'].fields_by_name['slow_op_sample_rate']._loaded_options = None
  _globals['_MONGODCONFIG4_2_OPERATIONPROFILING'].fields_by_name['slow_op_sample_rate']._serialized_options = b'\372\3071\0030-1'
  _globals['_MONGODCONFIG4_2_NETWORK_COMPRESSION'].fields_by_name['compressors']._loaded_options = None
  _globals['_MONGODCONFIG4_2_NETWORK_COMPRESSION'].fields_by_name['compressors']._serialized_options = b'\202\3101\0031-3'
  _globals['_MONGODCONFIG4_2_NETWORK'].fields_by_name['max_incoming_connections']._loaded_options = None
  _globals['_MONGODCONFIG4_2_NETWORK'].fields_by_name['max_incoming_connections']._serialized_options = b'\372\3071\01010-16384'
  _globals['_MONGOCFGCONFIG4_2_OPERATIONPROFILING'].fields_by_name['slow_op_threshold']._loaded_options = None
  _globals['_MONGOCFGCONFIG4_2_OPERATIONPROFILING'].fields_by_name['slow_op_threshold']._serialized_options = b'\372\3071\002>0'
  _globals['_MONGOCFGCONFIG4_2_NETWORK'].fields_by_name['max_incoming_connections']._loaded_options = None
  _globals['_MONGOCFGCONFIG4_2_NETWORK'].fields_by_name['max_incoming_connections']._serialized_options = b'\372\3071\01010-16384'
  _globals['_MONGOSCONFIG4_2_NETWORK_COMPRESSION'].fields_by_name['compressors']._loaded_options = None
  _globals['_MONGOSCONFIG4_2_NETWORK_COMPRESSION'].fields_by_name['compressors']._serialized_options = b'\202\3101\0031-3'
  _globals['_MONGOSCONFIG4_2_NETWORK'].fields_by_name['max_incoming_connections']._loaded_options = None
  _globals['_MONGOSCONFIG4_2_NETWORK'].fields_by_name['max_incoming_connections']._serialized_options = b'\372\3071\01010-16384'
  _globals['_MONGODCONFIG4_2']._serialized_start=155
  _globals['_MONGODCONFIG4_2']._serialized_end=2278
  _globals['_MONGODCONFIG4_2_STORAGE']._serialized_start=517
  _globals['_MONGODCONFIG4_2_STORAGE']._serialized_end=1497
  _globals['_MONGODCONFIG4_2_STORAGE_WIREDTIGER']._serialized_start=708
  _globals['_MONGODCONFIG4_2_STORAGE_WIREDTIGER']._serialized_end=1421
  _globals['_MONGODCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG']._serialized_start=1052
  _globals['_MONGODCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG']._serialized_end=1119
  _globals['_MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG']._serialized_start=1122
  _globals['_MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG']._serialized_end=1350
  _globals['_MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR']._serialized_start=1268
  _globals['_MONGODCONFIG4_2_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR']._serialized_end=1350
  _globals['_MONGODCONFIG4_2_STORAGE_WIREDTIGER_INDEXCONFIG']._serialized_start=1352
  _globals['_MONGODCONFIG4_2_STORAGE_WIREDTIGER_INDEXCONFIG']._serialized_end=1421
  _globals['_MONGODCONFIG4_2_STORAGE_JOURNAL']._serialized_start=1423
  _globals['_MONGODCONFIG4_2_STORAGE_JOURNAL']._serialized_end=1497
  _globals['_MONGODCONFIG4_2_OPERATIONPROFILING']._serialized_start=1500
  _globals['_MONGODCONFIG4_2_OPERATIONPROFILING']._serialized_end=1804
  _globals['_MONGODCONFIG4_2_OPERATIONPROFILING_MODE']._serialized_start=1745
  _globals['_MONGODCONFIG4_2_OPERATIONPROFILING_MODE']._serialized_end=1804
  _globals['_MONGODCONFIG4_2_NETWORK']._serialized_start=1807
  _globals['_MONGODCONFIG4_2_NETWORK']._serialized_end=2205
  _globals['_MONGODCONFIG4_2_NETWORK_COMPRESSION']._serialized_start=1990
  _globals['_MONGODCONFIG4_2_NETWORK_COMPRESSION']._serialized_end=2205
  _globals['_MONGODCONFIG4_2_NETWORK_COMPRESSION_COMPRESSOR']._serialized_start=2119
  _globals['_MONGODCONFIG4_2_NETWORK_COMPRESSION_COMPRESSOR']._serialized_end=2205
  _globals['_MONGODCONFIG4_2_SETPARAMETER']._serialized_start=2207
  _globals['_MONGODCONFIG4_2_SETPARAMETER']._serialized_end=2278
  _globals['_MONGOCFGCONFIG4_2']._serialized_start=2281
  _globals['_MONGOCFGCONFIG4_2']._serialized_end=3189
  _globals['_MONGOCFGCONFIG4_2_STORAGE']._serialized_start=2562
  _globals['_MONGOCFGCONFIG4_2_STORAGE']._serialized_end=2860
  _globals['_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER']._serialized_start=2669
  _globals['_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER']._serialized_end=2860
  _globals['_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG']._serialized_start=1052
  _globals['_MONGOCFGCONFIG4_2_STORAGE_WIREDTIGER_ENGINECONFIG']._serialized_end=1119
  _globals['_MONGOCFGCONFIG4_2_OPERATIONPROFILING']._serialized_start=2863
  _globals['_MONGOCFGCONFIG4_2_OPERATIONPROFILING']._serialized_end=3101
  _globals['_MONGOCFGCONFIG4_2_OPERATIONPROFILING_MODE']._serialized_start=1745
  _globals['_MONGOCFGCONFIG4_2_OPERATIONPROFILING_MODE']._serialized_end=1804
  _globals['_MONGOCFGCONFIG4_2_NETWORK']._serialized_start=1807
  _globals['_MONGOCFGCONFIG4_2_NETWORK']._serialized_end=1893
  _globals['_MONGOSCONFIG4_2']._serialized_start=3192
  _globals['_MONGOSCONFIG4_2']._serialized_end=3684
  _globals['_MONGOSCONFIG4_2_NETWORK']._serialized_start=3286
  _globals['_MONGOSCONFIG4_2_NETWORK']._serialized_end=3684
  _globals['_MONGOSCONFIG4_2_NETWORK_COMPRESSION']._serialized_start=3469
  _globals['_MONGOSCONFIG4_2_NETWORK_COMPRESSION']._serialized_end=3684
  _globals['_MONGOSCONFIG4_2_NETWORK_COMPRESSION_COMPRESSOR']._serialized_start=2119
  _globals['_MONGOSCONFIG4_2_NETWORK_COMPRESSION_COMPRESSOR']._serialized_end=2205
  _globals['_MONGODCONFIGSET4_2']._serialized_start=3687
  _globals['_MONGODCONFIGSET4_2']._serialized_end=3937
  _globals['_MONGOCFGCONFIGSET4_2']._serialized_start=3940
  _globals['_MONGOCFGCONFIGSET4_2']._serialized_end=4198
  _globals['_MONGOSCONFIGSET4_2']._serialized_start=4201
  _globals['_MONGOSCONFIGSET4_2']._serialized_end=4451
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RegisterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    AGENT_VERSION_FIELD_NUMBER: builtins.int
    compute_instance_id: builtins.str
    agent_version: builtins.str
    def __init__(
        self,
        *,
        compute_instance_id: builtins.str = ...,
        agent_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_version", b"agent_version", "compute_instance_id", b"compute_instance_id"]) -> None: ...

global___RegisterRequest = RegisterRequest

@typing.final
class RegisterResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGENT_INSTANCE_ID_FIELD_NUMBER: builtins.int
    agent_instance_id: builtins.str
    def __init__(
        self,
        *,
        agent_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_instance_id", b"agent_instance_id"]) -> None: ...

global___RegisterResponse = RegisterResponse

@typing.final
class ExternalAgentRegisterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AGENT_VERSION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    compute_instance_id: builtins.str
    name: builtins.str
    agent_version: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        compute_instance_id: builtins.str = ...,
        name: builtins.str = ...,
        agent_version: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_version", b"agent_version", "compute_instance_id", b"compute_instance_id", "folder_id", b"folder_id", "labels", b"labels", "name", b"name"]) -> None: ...

global___ExternalAgentRegisterRequest = ExternalAgentRegisterRequest

@typing.final
class ExternalAgentRegisterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGENT_INSTANCE_ID_FIELD_NUMBER: builtins.int
    agent_instance_id: builtins.str
    def __init__(
        self,
        *,
        agent_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_instance_id", b"agent_instance_id"]) -> None: ...

global___ExternalAgentRegisterMetadata = ExternalAgentRegisterMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing
import yandex.cloud.mdb.kafka.v1.common_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Topic(google.protobuf.message.Message):
    """An Kafka topic.
    For more information, see the [Concepts -> Topics and partitions](/docs/managed-kafka/concepts/topics) section of the documentation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PARTITIONS_FIELD_NUMBER: builtins.int
    REPLICATION_FACTOR_FIELD_NUMBER: builtins.int
    TOPIC_CONFIG_2_8_FIELD_NUMBER: builtins.int
    TOPIC_CONFIG_3_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the topic."""
    cluster_id: builtins.str
    """ID of an Apache Kafka® cluster that the topic belongs to.

    To get the Apache Kafka® cluster ID, make a [ClusterService.List] request.
    """
    @property
    def partitions(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of the topic's partitions."""

    @property
    def replication_factor(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Amount of data copies (replicas) for the topic in the cluster."""

    @property
    def topic_config_2_8(self) -> global___TopicConfig2_8: ...
    @property
    def topic_config_3(self) -> global___TopicConfig3: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        partitions: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        replication_factor: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        topic_config_2_8: global___TopicConfig2_8 | None = ...,
        topic_config_3: global___TopicConfig3 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["partitions", b"partitions", "replication_factor", b"replication_factor", "topic_config", b"topic_config", "topic_config_2_8", b"topic_config_2_8", "topic_config_3", b"topic_config_3"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name", "partitions", b"partitions", "replication_factor", b"replication_factor", "topic_config", b"topic_config", "topic_config_2_8", b"topic_config_2_8", "topic_config_3", b"topic_config_3"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["topic_config", b"topic_config"]) -> typing.Literal["topic_config_2_8", "topic_config_3"] | None: ...

global___Topic = Topic

@typing.final
class TopicSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PARTITIONS_FIELD_NUMBER: builtins.int
    REPLICATION_FACTOR_FIELD_NUMBER: builtins.int
    TOPIC_CONFIG_2_8_FIELD_NUMBER: builtins.int
    TOPIC_CONFIG_3_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the topic."""
    @property
    def partitions(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of the topic's partitions."""

    @property
    def replication_factor(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Amount of copies of a topic data kept in the cluster."""

    @property
    def topic_config_2_8(self) -> global___TopicConfig2_8: ...
    @property
    def topic_config_3(self) -> global___TopicConfig3: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        partitions: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        replication_factor: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        topic_config_2_8: global___TopicConfig2_8 | None = ...,
        topic_config_3: global___TopicConfig3 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["partitions", b"partitions", "replication_factor", b"replication_factor", "topic_config", b"topic_config", "topic_config_2_8", b"topic_config_2_8", "topic_config_3", b"topic_config_3"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "partitions", b"partitions", "replication_factor", b"replication_factor", "topic_config", b"topic_config", "topic_config_2_8", b"topic_config_2_8", "topic_config_3", b"topic_config_3"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["topic_config", b"topic_config"]) -> typing.Literal["topic_config_2_8", "topic_config_3"] | None: ...

global___TopicSpec = TopicSpec

@typing.final
class TopicConfig2_8(google.protobuf.message.Message):
    """A topic settings for 2.8"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _CleanupPolicy:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CleanupPolicyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TopicConfig2_8._CleanupPolicy.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CLEANUP_POLICY_UNSPECIFIED: TopicConfig2_8._CleanupPolicy.ValueType  # 0
        CLEANUP_POLICY_DELETE: TopicConfig2_8._CleanupPolicy.ValueType  # 1
        """This policy discards log segments when either their retention time or log size limit is reached. See also: [KafkaConfig2_8.log_retention_ms] and other similar parameters."""
        CLEANUP_POLICY_COMPACT: TopicConfig2_8._CleanupPolicy.ValueType  # 2
        """This policy compacts messages in log."""
        CLEANUP_POLICY_COMPACT_AND_DELETE: TopicConfig2_8._CleanupPolicy.ValueType  # 3
        """This policy use both compaction and deletion for messages and log segments."""

    class CleanupPolicy(_CleanupPolicy, metaclass=_CleanupPolicyEnumTypeWrapper): ...
    CLEANUP_POLICY_UNSPECIFIED: TopicConfig2_8.CleanupPolicy.ValueType  # 0
    CLEANUP_POLICY_DELETE: TopicConfig2_8.CleanupPolicy.ValueType  # 1
    """This policy discards log segments when either their retention time or log size limit is reached. See also: [KafkaConfig2_8.log_retention_ms] and other similar parameters."""
    CLEANUP_POLICY_COMPACT: TopicConfig2_8.CleanupPolicy.ValueType  # 2
    """This policy compacts messages in log."""
    CLEANUP_POLICY_COMPACT_AND_DELETE: TopicConfig2_8.CleanupPolicy.ValueType  # 3
    """This policy use both compaction and deletion for messages and log segments."""

    CLEANUP_POLICY_FIELD_NUMBER: builtins.int
    COMPRESSION_TYPE_FIELD_NUMBER: builtins.int
    DELETE_RETENTION_MS_FIELD_NUMBER: builtins.int
    FILE_DELETE_DELAY_MS_FIELD_NUMBER: builtins.int
    FLUSH_MESSAGES_FIELD_NUMBER: builtins.int
    FLUSH_MS_FIELD_NUMBER: builtins.int
    MIN_COMPACTION_LAG_MS_FIELD_NUMBER: builtins.int
    RETENTION_BYTES_FIELD_NUMBER: builtins.int
    RETENTION_MS_FIELD_NUMBER: builtins.int
    MAX_MESSAGE_BYTES_FIELD_NUMBER: builtins.int
    MIN_INSYNC_REPLICAS_FIELD_NUMBER: builtins.int
    SEGMENT_BYTES_FIELD_NUMBER: builtins.int
    PREALLOCATE_FIELD_NUMBER: builtins.int
    cleanup_policy: global___TopicConfig2_8.CleanupPolicy.ValueType
    """Retention policy to use on old log messages."""
    compression_type: yandex.cloud.mdb.kafka.v1.common_pb2.CompressionType.ValueType
    """The compression type for a given topic."""
    @property
    def delete_retention_ms(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The amount of time in milliseconds to retain delete tombstone markers for log compacted topics."""

    @property
    def file_delete_delay_ms(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The time to wait before deleting a file from the filesystem."""

    @property
    def flush_messages(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of messages accumulated on a log partition before messages are flushed to disk.

        This setting overrides the cluster-level [KafkaConfig2_8.log_flush_interval_messages] setting on the topic level.
        """

    @property
    def flush_ms(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum time in milliseconds that a message in the topic is kept in memory before flushed to disk.

        This setting overrides the cluster-level [KafkaConfig2_8.log_flush_interval_ms] setting on the topic level.
        """

    @property
    def min_compaction_lag_ms(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The minimum time in milliseconds a message will remain uncompacted in the log."""

    @property
    def retention_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum size a partition can grow to before Kafka will discard old log segments to free up space if the `delete` [cleanup_policy] is in effect.
        It is helpful if you need to control the size of log due to limited disk space.

        This setting overrides the cluster-level [KafkaConfig2_8.log_retention_bytes] setting on the topic level.
        """

    @property
    def retention_ms(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of milliseconds to keep a log segment's file before deleting it.

        This setting overrides the cluster-level [KafkaConfig2_8.log_retention_ms] setting on the topic level.
        """

    @property
    def max_message_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The largest record batch size allowed in topic."""

    @property
    def min_insync_replicas(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """This configuration specifies the minimum number of replicas that must acknowledge a write to topic for the write
        to be considered successful (when a producer sets acks to "all").
        """

    @property
    def segment_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """This configuration controls the segment file size for the log. Retention and cleaning is always done a file
        at a time so a larger segment size means fewer files but less granular control over retention.

        This setting overrides the cluster-level [KafkaConfig2_8.log_segment_bytes] setting on the topic level.
        """

    @property
    def preallocate(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """True if we should preallocate the file on disk when creating a new log segment.

        This setting overrides the cluster-level [KafkaConfig2_8.log_preallocate] setting on the topic level.
        Deprecated. Feature useless for Yandex Cloud.
        """

    def __init__(
        self,
        *,
        cleanup_policy: global___TopicConfig2_8.CleanupPolicy.ValueType = ...,
        compression_type: yandex.cloud.mdb.kafka.v1.common_pb2.CompressionType.ValueType = ...,
        delete_retention_ms: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        file_delete_delay_ms: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        flush_messages: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        flush_ms: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        min_compaction_lag_ms: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        retention_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        retention_ms: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_message_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        min_insync_replicas: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        segment_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        preallocate: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["delete_retention_ms", b"delete_retention_ms", "file_delete_delay_ms", b"file_delete_delay_ms", "flush_messages", b"flush_messages", "flush_ms", b"flush_ms", "max_message_bytes", b"max_message_bytes", "min_compaction_lag_ms", b"min_compaction_lag_ms", "min_insync_replicas", b"min_insync_replicas", "preallocate", b"preallocate", "retention_bytes", b"retention_bytes", "retention_ms", b"retention_ms", "segment_bytes", b"segment_bytes"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cleanup_policy", b"cleanup_policy", "compression_type", b"compression_type", "delete_retention_ms", b"delete_retention_ms", "file_delete_delay_ms", b"file_delete_delay_ms", "flush_messages", b"flush_messages", "flush_ms", b"flush_ms", "max_message_bytes", b"max_message_bytes", "min_compaction_lag_ms", b"min_compaction_lag_ms", "min_insync_replicas", b"min_insync_replicas", "preallocate", b"preallocate", "retention_bytes", b"retention_bytes", "retention_ms", b"retention_ms", "segment_bytes", b"segment_bytes"]) -> None: ...

global___TopicConfig2_8 = TopicConfig2_8

@typing.final
class TopicConfig3(google.protobuf.message.Message):
    """A topic settings for 3.x"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _CleanupPolicy:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CleanupPolicyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TopicConfig3._CleanupPolicy.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CLEANUP_POLICY_UNSPECIFIED: TopicConfig3._CleanupPolicy.ValueType  # 0
        CLEANUP_POLICY_DELETE: TopicConfig3._CleanupPolicy.ValueType  # 1
        """This policy discards log segments when either their retention time or log size limit is reached. See also: [KafkaConfig3.log_retention_ms] and other similar parameters."""
        CLEANUP_POLICY_COMPACT: TopicConfig3._CleanupPolicy.ValueType  # 2
        """This policy compacts messages in log."""
        CLEANUP_POLICY_COMPACT_AND_DELETE: TopicConfig3._CleanupPolicy.ValueType  # 3
        """This policy use both compaction and deletion for messages and log segments."""

    class CleanupPolicy(_CleanupPolicy, metaclass=_CleanupPolicyEnumTypeWrapper): ...
    CLEANUP_POLICY_UNSPECIFIED: TopicConfig3.CleanupPolicy.ValueType  # 0
    CLEANUP_POLICY_DELETE: TopicConfig3.CleanupPolicy.ValueType  # 1
    """This policy discards log segments when either their retention time or log size limit is reached. See also: [KafkaConfig3.log_retention_ms] and other similar parameters."""
    CLEANUP_POLICY_COMPACT: TopicConfig3.CleanupPolicy.ValueType  # 2
    """This policy compacts messages in log."""
    CLEANUP_POLICY_COMPACT_AND_DELETE: TopicConfig3.CleanupPolicy.ValueType  # 3
    """This policy use both compaction and deletion for messages and log segments."""

    CLEANUP_POLICY_FIELD_NUMBER: builtins.int
    COMPRESSION_TYPE_FIELD_NUMBER: builtins.int
    DELETE_RETENTION_MS_FIELD_NUMBER: builtins.int
    FILE_DELETE_DELAY_MS_FIELD_NUMBER: builtins.int
    FLUSH_MESSAGES_FIELD_NUMBER: builtins.int
    FLUSH_MS_FIELD_NUMBER: builtins.int
    MIN_COMPACTION_LAG_MS_FIELD_NUMBER: builtins.int
    RETENTION_BYTES_FIELD_NUMBER: builtins.int
    RETENTION_MS_FIELD_NUMBER: builtins.int
    MAX_MESSAGE_BYTES_FIELD_NUMBER: builtins.int
    MIN_INSYNC_REPLICAS_FIELD_NUMBER: builtins.int
    SEGMENT_BYTES_FIELD_NUMBER: builtins.int
    PREALLOCATE_FIELD_NUMBER: builtins.int
    cleanup_policy: global___TopicConfig3.CleanupPolicy.ValueType
    """Retention policy to use on old log messages."""
    compression_type: yandex.cloud.mdb.kafka.v1.common_pb2.CompressionType.ValueType
    """The compression type for a given topic."""
    @property
    def delete_retention_ms(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The amount of time in milliseconds to retain delete tombstone markers for log compacted topics."""

    @property
    def file_delete_delay_ms(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The time to wait before deleting a file from the filesystem."""

    @property
    def flush_messages(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of messages accumulated on a log partition before messages are flushed to disk.

        This setting overrides the cluster-level [KafkaConfig3.log_flush_interval_messages] setting on the topic level.
        """

    @property
    def flush_ms(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum time in milliseconds that a message in the topic is kept in memory before flushed to disk.

        This setting overrides the cluster-level [KafkaConfig3.log_flush_interval_ms] setting on the topic level.
        """

    @property
    def min_compaction_lag_ms(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The minimum time in milliseconds a message will remain uncompacted in the log."""

    @property
    def retention_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum size a partition can grow to before Kafka will discard old log segments to free up space if the `delete` [cleanup_policy] is in effect.
        It is helpful if you need to control the size of log due to limited disk space.

        This setting overrides the cluster-level [KafkaConfig3.log_retention_bytes] setting on the topic level.
        """

    @property
    def retention_ms(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of milliseconds to keep a log segment's file before deleting it.

        This setting overrides the cluster-level [KafkaConfig3.log_retention_ms] setting on the topic level.
        """

    @property
    def max_message_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The largest record batch size allowed in topic."""

    @property
    def min_insync_replicas(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """This configuration specifies the minimum number of replicas that must acknowledge a write to topic for the write
        to be considered successful (when a producer sets acks to "all").
        """

    @property
    def segment_bytes(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """This configuration controls the segment file size for the log. Retention and cleaning is always done a file
        at a time so a larger segment size means fewer files but less granular control over retention.

        This setting overrides the cluster-level [KafkaConfig3.log_segment_bytes] setting on the topic level.
        """

    @property
    def preallocate(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """True if we should preallocate the file on disk when creating a new log segment.

        This setting overrides the cluster-level [KafkaConfig3.log_preallocate] setting on the topic level.
        Deprecated. Feature useless for Yandex Cloud.
        """

    def __init__(
        self,
        *,
        cleanup_policy: global___TopicConfig3.CleanupPolicy.ValueType = ...,
        compression_type: yandex.cloud.mdb.kafka.v1.common_pb2.CompressionType.ValueType = ...,
        delete_retention_ms: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        file_delete_delay_ms: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        flush_messages: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        flush_ms: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        min_compaction_lag_ms: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        retention_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        retention_ms: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_message_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        min_insync_replicas: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        segment_bytes: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        preallocate: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["delete_retention_ms", b"delete_retention_ms", "file_delete_delay_ms", b"file_delete_delay_ms", "flush_messages", b"flush_messages", "flush_ms", b"flush_ms", "max_message_bytes", b"max_message_bytes", "min_compaction_lag_ms", b"min_compaction_lag_ms", "min_insync_replicas", b"min_insync_replicas", "preallocate", b"preallocate", "retention_bytes", b"retention_bytes", "retention_ms", b"retention_ms", "segment_bytes", b"segment_bytes"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cleanup_policy", b"cleanup_policy", "compression_type", b"compression_type", "delete_retention_ms", b"delete_retention_ms", "file_delete_delay_ms", b"file_delete_delay_ms", "flush_messages", b"flush_messages", "flush_ms", b"flush_ms", "max_message_bytes", b"max_message_bytes", "min_compaction_lag_ms", b"min_compaction_lag_ms", "min_insync_replicas", b"min_insync_replicas", "preallocate", b"preallocate", "retention_bytes", b"retention_bytes", "retention_ms", b"retention_ms", "segment_bytes", b"segment_bytes"]) -> None: ...

global___TopicConfig3 = TopicConfig3



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/assistants/v1/threads/message_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/assistants/v1/threads/message_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.assistants.v1.threads import message_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;yandex/cloud/ai/assistants/v1/threads/message_service.proto\x12%yandex.cloud.ai.assistants.v1.threads\x1a\x33yandex/cloud/ai/assistants/v1/threads/message.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\"\xc4\x02\n\x14\x43reateMessageRequest\x12\x17\n\tthread_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12=\n\x06\x61uthor\x18\x02 \x01(\x0b\x32-.yandex.cloud.ai.assistants.v1.threads.Author\x12W\n\x06labels\x18\x03 \x03(\x0b\x32G.yandex.cloud.ai.assistants.v1.threads.CreateMessageRequest.LabelsEntry\x12L\n\x07\x63ontent\x18\x04 \x01(\x0b\x32\x35.yandex.cloud.ai.assistants.v1.threads.MessageContentB\x04\xe8\xc7\x31\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"F\n\x11GetMessageRequest\x12\x17\n\tthread_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\nmessage_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\".\n\x13ListMessagesRequest\x12\x17\n\tthread_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xe4\x03\n\x0eMessageService\x12\x99\x01\n\x06\x43reate\x12;.yandex.cloud.ai.assistants.v1.threads.CreateMessageRequest\x1a..yandex.cloud.ai.assistants.v1.threads.Message\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/assistants/v1/messages:\x01*\x12\x9d\x01\n\x03Get\x12\x38.yandex.cloud.ai.assistants.v1.threads.GetMessageRequest\x1a..yandex.cloud.ai.assistants.v1.threads.Message\",\x82\xd3\xe4\x93\x02&\x12$/assistants/v1/messages/{message_id}\x12\x95\x01\n\x04List\x12:.yandex.cloud.ai.assistants.v1.threads.ListMessagesRequest\x1a..yandex.cloud.ai.assistants.v1.threads.Message\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/assistants/v1/messages0\x01\x42~\n)yandex.cloud.api.ai.assistants.v1.threadsZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/threads;threadsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.threads.message_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.ai.assistants.v1.threadsZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/threads;threads'
  _globals['_CREATEMESSAGEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEMESSAGEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEMESSAGEREQUEST'].fields_by_name['thread_id']._loaded_options = None
  _globals['_CREATEMESSAGEREQUEST'].fields_by_name['thread_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEMESSAGEREQUEST'].fields_by_name['content']._loaded_options = None
  _globals['_CREATEMESSAGEREQUEST'].fields_by_name['content']._serialized_options = b'\350\3071\001'
  _globals['_GETMESSAGEREQUEST'].fields_by_name['thread_id']._loaded_options = None
  _globals['_GETMESSAGEREQUEST'].fields_by_name['thread_id']._serialized_options = b'\350\3071\001'
  _globals['_GETMESSAGEREQUEST'].fields_by_name['message_id']._loaded_options = None
  _globals['_GETMESSAGEREQUEST'].fields_by_name['message_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTMESSAGESREQUEST'].fields_by_name['thread_id']._loaded_options = None
  _globals['_LISTMESSAGESREQUEST'].fields_by_name['thread_id']._serialized_options = b'\350\3071\001'
  _globals['_MESSAGESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_MESSAGESERVICE'].methods_by_name['Create']._serialized_options = b'\202\323\344\223\002\034\"\027/assistants/v1/messages:\001*'
  _globals['_MESSAGESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_MESSAGESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002&\022$/assistants/v1/messages/{message_id}'
  _globals['_MESSAGESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_MESSAGESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\031\022\027/assistants/v1/messages'
  _globals['_CREATEMESSAGEREQUEST']._serialized_start=217
  _globals['_CREATEMESSAGEREQUEST']._serialized_end=541
  _globals['_CREATEMESSAGEREQUEST_LABELSENTRY']._serialized_start=496
  _globals['_CREATEMESSAGEREQUEST_LABELSENTRY']._serialized_end=541
  _globals['_GETMESSAGEREQUEST']._serialized_start=543
  _globals['_GETMESSAGEREQUEST']._serialized_end=613
  _globals['_LISTMESSAGESREQUEST']._serialized_start=615
  _globals['_LISTMESSAGESREQUEST']._serialized_end=661
  _globals['_MESSAGESERVICE']._serialized_start=664
  _globals['_MESSAGESERVICE']._serialized_end=1148
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.video.v1.style_preset_pb2
import yandex.cloud.video.v1.style_preset_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class StylePresetServiceStub:
    """StylePreset management service.
    Provides methods for creating, retrieving, updating, and deleting style presets,
    which define the visual appearance and layout of video players and associated widgets.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.style_preset_service_pb2.GetStylePresetRequest,
        yandex.cloud.video.v1.style_preset_pb2.StylePreset,
    ]
    """Retrieves detailed information about a specific style preset by its ID.
    Returns all style preset properties, colors, layout settings, and widget configurations.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.style_preset_service_pb2.ListStylePresetsRequest,
        yandex.cloud.video.v1.style_preset_service_pb2.ListStylePresetsResponse,
    ]
    """Lists all style presets in a specific channel with pagination support.
    Results can be filtered and sorted using the provided parameters.
    """

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.style_preset_service_pb2.CreateStylePresetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new style preset in the specified channel with the provided visual settings.
    Style presets define the appearance of players, including colors, spacing, borders, and widgets.
    """

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.style_preset_service_pb2.UpdateStylePresetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates an existing style preset's properties and visual settings.
    Only fields specified in the field_mask will be updated.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.style_preset_service_pb2.DeleteStylePresetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a specific style preset by its ID.
    This operation will fail if the style preset is currently in use by any videos, streams, or playlists.
    """

class StylePresetServiceAsyncStub:
    """StylePreset management service.
    Provides methods for creating, retrieving, updating, and deleting style presets,
    which define the visual appearance and layout of video players and associated widgets.
    """

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.style_preset_service_pb2.GetStylePresetRequest,
        yandex.cloud.video.v1.style_preset_pb2.StylePreset,
    ]
    """Retrieves detailed information about a specific style preset by its ID.
    Returns all style preset properties, colors, layout settings, and widget configurations.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.style_preset_service_pb2.ListStylePresetsRequest,
        yandex.cloud.video.v1.style_preset_service_pb2.ListStylePresetsResponse,
    ]
    """Lists all style presets in a specific channel with pagination support.
    Results can be filtered and sorted using the provided parameters.
    """

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.style_preset_service_pb2.CreateStylePresetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new style preset in the specified channel with the provided visual settings.
    Style presets define the appearance of players, including colors, spacing, borders, and widgets.
    """

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.style_preset_service_pb2.UpdateStylePresetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates an existing style preset's properties and visual settings.
    Only fields specified in the field_mask will be updated.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.style_preset_service_pb2.DeleteStylePresetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a specific style preset by its ID.
    This operation will fail if the style preset is currently in use by any videos, streams, or playlists.
    """

class StylePresetServiceServicer(metaclass=abc.ABCMeta):
    """StylePreset management service.
    Provides methods for creating, retrieving, updating, and deleting style presets,
    which define the visual appearance and layout of video players and associated widgets.
    """

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.video.v1.style_preset_service_pb2.GetStylePresetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.style_preset_pb2.StylePreset, collections.abc.Awaitable[yandex.cloud.video.v1.style_preset_pb2.StylePreset]]:
        """Retrieves detailed information about a specific style preset by its ID.
        Returns all style preset properties, colors, layout settings, and widget configurations.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.video.v1.style_preset_service_pb2.ListStylePresetsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.style_preset_service_pb2.ListStylePresetsResponse, collections.abc.Awaitable[yandex.cloud.video.v1.style_preset_service_pb2.ListStylePresetsResponse]]:
        """Lists all style presets in a specific channel with pagination support.
        Results can be filtered and sorted using the provided parameters.
        """

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.video.v1.style_preset_service_pb2.CreateStylePresetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a new style preset in the specified channel with the provided visual settings.
        Style presets define the appearance of players, including colors, spacing, borders, and widgets.
        """

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.video.v1.style_preset_service_pb2.UpdateStylePresetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates an existing style preset's properties and visual settings.
        Only fields specified in the field_mask will be updated.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.video.v1.style_preset_service_pb2.DeleteStylePresetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes a specific style preset by its ID.
        This operation will fail if the style preset is currently in use by any videos, streams, or playlists.
        """

def add_StylePresetServiceServicer_to_server(servicer: StylePresetServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/oauth_client.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/oauth_client.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/iam/v1/oauth_client.proto\x12\x13yandex.cloud.iam.v1\"\xe4\x01\n\x0bOAuthClient\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rredirect_uris\x18\x03 \x03(\t\x12\x0e\n\x06scopes\x18\x04 \x03(\t\x12\x11\n\tfolder_id\x18\x05 \x01(\t\x12\x37\n\x06status\x18\x06 \x01(\x0e\x32\'.yandex.cloud.iam.v1.OAuthClient.Status\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x42V\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.oauth_client_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _globals['_OAUTHCLIENT']._serialized_start=64
  _globals['_OAUTHCLIENT']._serialized_end=292
  _globals['_OAUTHCLIENT_STATUS']._serialized_start=220
  _globals['_OAUTHCLIENT_STATUS']._serialized_end=292
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.clouddesktop.v1.desktop_image_pb2
import yandex.cloud.clouddesktop.v1.desktop_image_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class DesktopImageServiceStub:
    """A service for managing desktop images."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.ListDesktopImagesRequest,
        yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.ListDesktopImagesResponse,
    ]
    """Lists desktop images in the specified folder."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.GetDesktopImageRequest,
        yandex.cloud.clouddesktop.v1.desktop_image_pb2.DesktopImage,
    ]
    """Returns the specified desktop image."""

    Copy: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.CopyDesktopImageRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Copies the specified image to desktop image."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.UpdateDesktopImageRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates desktop image properties."""

    CopyFromDesktop: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.CopyFromDesktopRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Copies the specified desktop image from the specified desktop."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.DeleteDesktopImageRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified desktop image."""

class DesktopImageServiceAsyncStub:
    """A service for managing desktop images."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.ListDesktopImagesRequest,
        yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.ListDesktopImagesResponse,
    ]
    """Lists desktop images in the specified folder."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.GetDesktopImageRequest,
        yandex.cloud.clouddesktop.v1.desktop_image_pb2.DesktopImage,
    ]
    """Returns the specified desktop image."""

    Copy: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.CopyDesktopImageRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Copies the specified image to desktop image."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.UpdateDesktopImageRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates desktop image properties."""

    CopyFromDesktop: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.CopyFromDesktopRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Copies the specified desktop image from the specified desktop."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.DeleteDesktopImageRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified desktop image."""

class DesktopImageServiceServicer(metaclass=abc.ABCMeta):
    """A service for managing desktop images."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.ListDesktopImagesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.ListDesktopImagesResponse, collections.abc.Awaitable[yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.ListDesktopImagesResponse]]:
        """Lists desktop images in the specified folder."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.GetDesktopImageRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.clouddesktop.v1.desktop_image_pb2.DesktopImage, collections.abc.Awaitable[yandex.cloud.clouddesktop.v1.desktop_image_pb2.DesktopImage]]:
        """Returns the specified desktop image."""

    @abc.abstractmethod
    def Copy(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.CopyDesktopImageRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Copies the specified image to desktop image."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.UpdateDesktopImageRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates desktop image properties."""

    @abc.abstractmethod
    def CopyFromDesktop(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.CopyFromDesktopRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Copies the specified desktop image from the specified desktop."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_image_service_pb2.DeleteDesktopImageRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified desktop image."""

def add_DesktopImageServiceServicer_to_server(servicer: DesktopImageServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.apploadbalancer.v1.load_balancer_pb2
import yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class LoadBalancerServiceStub:
    """A set of methods for managing application load balancers."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.GetLoadBalancerRequest,
        yandex.cloud.apploadbalancer.v1.load_balancer_pb2.LoadBalancer,
    ]
    """Returns the specified application load balancer.

    To get the list of all available application load balancers, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.ListLoadBalancersRequest,
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.ListLoadBalancersResponse,
    ]
    """Lists application load balancers in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.CreateLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an application load balancer in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.UpdateLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified application load balancer."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.DeleteLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified application load balancer."""

    Start: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.StartLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts the specified application load balancer."""

    Stop: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.StopLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops the specified application load balancer."""

    AddListener: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.AddListenerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """AddListener/UpdateListener technically do the same, but have different semantics.

    Adds a listener to the specified application load balancer.
    """

    RemoveListener: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.RemoveListenerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified listener."""

    UpdateListener: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.UpdateListenerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified listener of the specified application load balancer."""

    AddSniMatch: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.AddSniMatchRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a SNI handler to the specified listener.

    This request does not allow to add [TlsListener.default_handler]. Make an [UpdateListener] request instead.
    """

    UpdateSniMatch: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.UpdateSniMatchRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified SNI handler of the specified listener.

    This request does not allow to update [TlsListener.default_handler]. Make an [UpdateListener] request instead.
    """

    RemoveSniMatch: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.RemoveSniMatchRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified SNI handler.

    This request does not allow to delete [TlsListener.default_handler].
    """

    GetTargetStates: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.GetTargetStatesRequest,
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.GetTargetStatesResponse,
    ]
    """Returns the statuses of all targets of the specified backend group in all their availability zones."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.ListLoadBalancerOperationsRequest,
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.ListLoadBalancerOperationsResponse,
    ]
    """Lists operations for the specified application load balancer."""

    StartZonalShift: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.StartZonalShiftRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Start ZonalShift for the specified load balancer."""

    CancelZonalShift: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.CancelZonalShiftRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Cancel ZonalShift for the specified load balancer."""

    DisableZones: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.DisableZonesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Disable L7 traffic routing in zones for the specified load balancer."""

    EnableZones: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.EnableZonesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Enable L7 traffic routing back in zones for the specified load balancer."""

class LoadBalancerServiceAsyncStub:
    """A set of methods for managing application load balancers."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.GetLoadBalancerRequest,
        yandex.cloud.apploadbalancer.v1.load_balancer_pb2.LoadBalancer,
    ]
    """Returns the specified application load balancer.

    To get the list of all available application load balancers, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.ListLoadBalancersRequest,
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.ListLoadBalancersResponse,
    ]
    """Lists application load balancers in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.CreateLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an application load balancer in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.UpdateLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified application load balancer."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.DeleteLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified application load balancer."""

    Start: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.StartLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts the specified application load balancer."""

    Stop: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.StopLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops the specified application load balancer."""

    AddListener: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.AddListenerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """AddListener/UpdateListener technically do the same, but have different semantics.

    Adds a listener to the specified application load balancer.
    """

    RemoveListener: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.RemoveListenerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified listener."""

    UpdateListener: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.UpdateListenerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified listener of the specified application load balancer."""

    AddSniMatch: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.AddSniMatchRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a SNI handler to the specified listener.

    This request does not allow to add [TlsListener.default_handler]. Make an [UpdateListener] request instead.
    """

    UpdateSniMatch: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.UpdateSniMatchRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified SNI handler of the specified listener.

    This request does not allow to update [TlsListener.default_handler]. Make an [UpdateListener] request instead.
    """

    RemoveSniMatch: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.RemoveSniMatchRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified SNI handler.

    This request does not allow to delete [TlsListener.default_handler].
    """

    GetTargetStates: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.GetTargetStatesRequest,
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.GetTargetStatesResponse,
    ]
    """Returns the statuses of all targets of the specified backend group in all their availability zones."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.ListLoadBalancerOperationsRequest,
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.ListLoadBalancerOperationsResponse,
    ]
    """Lists operations for the specified application load balancer."""

    StartZonalShift: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.StartZonalShiftRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Start ZonalShift for the specified load balancer."""

    CancelZonalShift: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.CancelZonalShiftRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Cancel ZonalShift for the specified load balancer."""

    DisableZones: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.DisableZonesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Disable L7 traffic routing in zones for the specified load balancer."""

    EnableZones: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.EnableZonesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Enable L7 traffic routing back in zones for the specified load balancer."""

class LoadBalancerServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing application load balancers."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.GetLoadBalancerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.apploadbalancer.v1.load_balancer_pb2.LoadBalancer, collections.abc.Awaitable[yandex.cloud.apploadbalancer.v1.load_balancer_pb2.LoadBalancer]]:
        """Returns the specified application load balancer.

        To get the list of all available application load balancers, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.ListLoadBalancersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.ListLoadBalancersResponse, collections.abc.Awaitable[yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.ListLoadBalancersResponse]]:
        """Lists application load balancers in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.CreateLoadBalancerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an application load balancer in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.UpdateLoadBalancerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified application load balancer."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.DeleteLoadBalancerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified application load balancer."""

    @abc.abstractmethod
    def Start(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.StartLoadBalancerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Starts the specified application load balancer."""

    @abc.abstractmethod
    def Stop(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.StopLoadBalancerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Stops the specified application load balancer."""

    @abc.abstractmethod
    def AddListener(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.AddListenerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """AddListener/UpdateListener technically do the same, but have different semantics.

        Adds a listener to the specified application load balancer.
        """

    @abc.abstractmethod
    def RemoveListener(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.RemoveListenerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified listener."""

    @abc.abstractmethod
    def UpdateListener(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.UpdateListenerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified listener of the specified application load balancer."""

    @abc.abstractmethod
    def AddSniMatch(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.AddSniMatchRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds a SNI handler to the specified listener.

        This request does not allow to add [TlsListener.default_handler]. Make an [UpdateListener] request instead.
        """

    @abc.abstractmethod
    def UpdateSniMatch(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.UpdateSniMatchRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified SNI handler of the specified listener.

        This request does not allow to update [TlsListener.default_handler]. Make an [UpdateListener] request instead.
        """

    @abc.abstractmethod
    def RemoveSniMatch(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.RemoveSniMatchRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified SNI handler.

        This request does not allow to delete [TlsListener.default_handler].
        """

    @abc.abstractmethod
    def GetTargetStates(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.GetTargetStatesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.GetTargetStatesResponse, collections.abc.Awaitable[yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.GetTargetStatesResponse]]:
        """Returns the statuses of all targets of the specified backend group in all their availability zones."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.ListLoadBalancerOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.ListLoadBalancerOperationsResponse, collections.abc.Awaitable[yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.ListLoadBalancerOperationsResponse]]:
        """Lists operations for the specified application load balancer."""

    @abc.abstractmethod
    def StartZonalShift(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.StartZonalShiftRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Start ZonalShift for the specified load balancer."""

    @abc.abstractmethod
    def CancelZonalShift(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.CancelZonalShiftRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Cancel ZonalShift for the specified load balancer."""

    @abc.abstractmethod
    def DisableZones(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.DisableZonesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Disable L7 traffic routing in zones for the specified load balancer."""

    @abc.abstractmethod
    def EnableZones(
        self,
        request: yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2.EnableZonesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Enable L7 traffic routing back in zones for the specified load balancer."""

def add_LoadBalancerServiceServicer_to_server(servicer: LoadBalancerServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class BatchInferenceServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Describe: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.DescribeBatchInferenceRequest,
        yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.DescribeBatchInferenceResponse,
    ]
    """Describes a concrete task"""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.ListBatchInferencesRequest,
        yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.ListBatchInferencesResponse,
    ]
    """Lists tasks in folder"""

    Cancel: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.CancelBatchInferenceRequest,
        yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.CancelBatchInferenceResponse,
    ]
    """Cancels a concrete task"""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.DeleteBatchInferenceRequest,
        yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.DeleteBatchInferenceResponse,
    ]
    """Deletes a concrete task"""

class BatchInferenceServiceAsyncStub:
    Describe: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.DescribeBatchInferenceRequest,
        yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.DescribeBatchInferenceResponse,
    ]
    """Describes a concrete task"""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.ListBatchInferencesRequest,
        yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.ListBatchInferencesResponse,
    ]
    """Lists tasks in folder"""

    Cancel: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.CancelBatchInferenceRequest,
        yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.CancelBatchInferenceResponse,
    ]
    """Cancels a concrete task"""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.DeleteBatchInferenceRequest,
        yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.DeleteBatchInferenceResponse,
    ]
    """Deletes a concrete task"""

class BatchInferenceServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Describe(
        self,
        request: yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.DescribeBatchInferenceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.DescribeBatchInferenceResponse, collections.abc.Awaitable[yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.DescribeBatchInferenceResponse]]:
        """Describes a concrete task"""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.ListBatchInferencesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.ListBatchInferencesResponse, collections.abc.Awaitable[yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.ListBatchInferencesResponse]]:
        """Lists tasks in folder"""

    @abc.abstractmethod
    def Cancel(
        self,
        request: yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.CancelBatchInferenceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.CancelBatchInferenceResponse, collections.abc.Awaitable[yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.CancelBatchInferenceResponse]]:
        """Cancels a concrete task"""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.DeleteBatchInferenceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.DeleteBatchInferenceResponse, collections.abc.Awaitable[yandex.cloud.ai.batch_inference.v1.batch_inference_service_pb2.DeleteBatchInferenceResponse]]:
        """Deletes a concrete task"""

def add_BatchInferenceServiceServicer_to_server(servicer: BatchInferenceServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
